@@ -40,6 +40,7 @@ from magicgui.widgets._bases.widget import Widget
 from magicgui.widgets._bases import ButtonWidget, ValueWidget
 from macrokit import Expr, Head, Symbol, symbol
 
+
 from .keybinding import as_shortcut
 from .mgui_ext import (
     AbstractAction,
@@ -49,14 +50,17 @@ from .mgui_ext import (
     _LabeledWidgetAction,
     mguiLike,
 )
-from .utils import get_parameters, define_callback, callable_to_classes
+from .utils import get_parameters, callable_to_classes
 from ._macro import GuiMacro
 
 from ..utils import (
     get_signature,
     iter_members,
-    extract_tooltip,
+    Tooltips,
     move_to_screen_center,
+    argcount,
+    is_instance_method,
+    method_as_getter,
     thread_worker,
 )
 from ..widgets import Separator, FreeWidget
@@ -93,10 +97,17 @@ def _stdout_raising(e, parent):
     print(f"{e.__class__.__name__}: {e}")
 
 
+def _napari_notification_raising(e, parent):
+    from napari.utils.notifications import show_error
+
+    show_error(str(e))
+
+
 class ErrorMode(Enum):
     msgbox = "msgbox"
     stderr = "stderr"
     stdout = "stdout"
+    napari = "napari"
 
     def get_handler(self):
         """Get error handler."""
@@ -127,6 +138,7 @@ ErrorModeHandlers = {
     ErrorMode.msgbox: _msgbox_raising,
     ErrorMode.stderr: _stderr_raising,
     ErrorMode.stdout: _stdout_raising,
+    ErrorMode.napari: _napari_notification_raising,
 }
 
 
@@ -589,7 +601,7 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
         func.__signature__ = obj_sig
 
         # Prepare a button or action
-        widget.tooltip = extract_tooltip(func)
+        widget.tooltip = Tooltips(func).desc
         widget._doc = func.__doc__
 
         # This block enables instance methods in "bind" or "choices" of ValueWidget.
@@ -610,16 +622,16 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
                 _arg_choices = _param.options.get("choices", None)
 
                 # If bound method is a class method, use self.method(widget).
-                if _is_instance_method(self, _arg_bind):
-                    _param.options["bind"] = _method_as_getter(self, _arg_bind)
+                if is_instance_method(_arg_bind):
+                    _param.options["bind"] = method_as_getter(self, _arg_bind)
 
                 # If a MagicFiled is bound, bind the value of the connected widget.
                 elif isinstance(_arg_bind, MagicField):
-                    _param.options["bind"] = _field_as_getter(self, _arg_bind)
+                    _param.options["bind"] = _arg_bind.as_remote_getter(self)
 
                 # If choices are provided by a class method, use self.method(widget).
-                if _is_instance_method(self, _arg_choices):
-                    _param.options["choices"] = _method_as_getter(self, _arg_choices)
+                if is_instance_method(_arg_choices):
+                    _param.options["choices"] = method_as_getter(self, _arg_choices)
 
             else:
                 _param = param
@@ -633,7 +645,7 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
         n_empty = len(
             [_wdg_cls for _wdg_cls in fgui_classes if _wdg_cls is EmptyWidget]
         )
-        nparams = _n_parameters(func) - n_empty
+        nparams = argcount(func) - n_empty
 
         if isinstance(func.__signature__, MagicMethodSignature):
             func.__signature__.additional_options = getattr(
@@ -743,7 +755,7 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
         """Iterate over all the child magic classes"""
         for child in self.__magicclass_children__:
             yield child
-            yield from child.__magicclass_children__
+            yield from child._iter_child_magicclasses()
 
 
 class BaseGui(MagicTemplate):
@@ -810,17 +822,11 @@ class ContainerLikeGui(BaseGui, mguiLike, MutableSequence):
         fld.name = fld.name or name
         action = fld.get_action(self)
 
-        if action.support_value:
+        if action.support_value and fld.record:
             # By default, set value function will be connected to the widget.
-            if fld.record:
-                getvalue = type(fld) is MagicField
-                f = value_widget_callback(self, action, name, getvalue=getvalue)
-                action.changed.connect(f)
-
-            # If the field has callbacks, connect it to the newly generated widget.
-            for callback in fld.callbacks:
-                # funcname = callback.__name__
-                action.changed.connect(define_callback(self, callback))
+            getvalue = type(fld) is MagicField
+            f = value_widget_callback(self, action, name, getvalue=getvalue)
+            action.changed.connect(f)
 
         return action
 
@@ -1029,11 +1035,6 @@ def wraps(template: Callable | inspect.Signature) -> Callable[[_C], _C]:
     return wrapper
 
 
-def _n_parameters(func: Callable):
-    """Count the number of parameters of a callable object."""
-    return len(inspect.signature(func).parameters)
-
-
 def _get_index(container: Container, widget_or_name: Widget | str) -> int:
     """
     Identical to container[widget_or_name], which sometimes doesn't work
@@ -1065,81 +1066,24 @@ def _child_that_has_widget(
     return child_instance
 
 
-_LOCALS = "<locals>."
-
-
-def _method_as_getter(self, getter: Callable):
-    qualname = getter.__qualname__
-    if _LOCALS in qualname:
-        qualname = qualname.split(_LOCALS)[-1]
-    *clsnames, funcname = qualname.split(".")
-    ins = self
-    self_cls = ins.__class__.__name__
-    if self_cls not in clsnames:
-        ns = ".".join(clsnames)
-        raise ValueError(
-            f"Method {funcname} is in namespace {ns}, so it is invisible "
-            f"from magicclass {self.__class__.__qualname__}"
-        )
-    i = clsnames.index(self_cls) + 1
-
-    for clsname in clsnames[i:]:
-        ins = getattr(ins, clsname)
-
-    def _func(w):
-        return getter(ins, w)
-
-    return _func
-
-
-def _field_as_getter(bgui: BaseGui, fld: MagicField):
-    """Called when a MagicField is used in Bound method."""
-    qualname = fld.parent_class.__qualname__
-    if _LOCALS in qualname:
-        qualname = qualname.split(_LOCALS)[-1]
-    clsnames = qualname.split(".")
-
-    def _func(w):
-        # First we have to know where (which instance) MagicField came from.
-        if bgui.__class__.__name__ not in clsnames:
-            ns = ".".join(clsnames)
-            raise ValueError(
-                f"Method {fld.name} is in namespace {ns}, so it is invisible "
-                f"from magicclass {bgui.__class__.__qualname__}"
-            )
-        i = clsnames.index(type(bgui).__name__) + 1
-        ins = bgui
-        for clsname in clsnames[i:]:
-            ins = getattr(ins, clsname, ins)
-
-        # Now, ins is an instance of parent_class.
-        # Extract correct widget from MagicField
-        _field_widget = fld.get_widget(ins)
-        if not hasattr(_field_widget, "value"):
-            raise TypeError(
-                f"MagicField {fld.name} does not return ValueWidget "
-                "thus cannot be used as a bound value."
-            )
-        return fld.as_getter(ins)(w)
-
-    return _func
-
-
-def _is_instance_method(self: MagicTemplate, func: Callable) -> bool:
-    # NOTE: following implementation is not compatible with @wraps
-    # if not callable(func):
-    #     return False
-    # classes = func.__qualname__.split(".")[:-1]
-    # return self.__class__.__name__ in classes
-    return isinstance(func, Callable) and _n_parameters(func) == 2
-
-
 def value_widget_callback(
-    gui: MagicTemplate, widget: ValueWidget, name: str, getvalue: bool = True
+    gui: MagicTemplate,
+    widget: ValueWidget,
+    name: str | list[str],
+    getvalue: bool = True,
 ):
     """Define a ValueWidget callback, including macro recording."""
-    sym_name = Symbol(name)
-    sym_value = Symbol("value")
+    if isinstance(name, str):
+        sym_name = Symbol(name)
+    else:
+        sym_name = Symbol(name[0])
+        for n in name[1:]:
+            sym_name = Expr(head=Head.getattr, args=[sym_name, n])
+
+    if getvalue:
+        sub = Expr(head=Head.getattr, args=[sym_name, Symbol("value")])  # name.value
+    else:
+        sub = sym_name
 
     def _set_value():
         if not widget.enabled or not gui.macro.active:
@@ -1149,11 +1093,6 @@ def value_widget_callback(
 
         gui.changed.emit(gui)
 
-        if getvalue:
-            sub = Expr(head=Head.getattr, args=[sym_name, sym_value])  # name.value
-        else:
-            sub = sym_name
-
         # Make an expression of
         # >>> x.name.value = value
         # or
